pub struct ConfigAggBridgeNote;Expand description
CONFIG_AGG_BRIDGE note.
This note is used to register a faucet in the bridge’s faucet and token registries. It carries the origin token address and faucet account ID, and is always public.
Implementations
Sourceimpl ConfigAggBridgeNote
impl ConfigAggBridgeNote
Sourcepub const NUM_STORAGE_ITEMS: usize = 7
pub const NUM_STORAGE_ITEMS: usize = 7
Expected number of storage items for a CONFIG_AGG_BRIDGE note. Layout: [origin_token_addr(5), faucet_id_suffix, faucet_id_prefix]
Sourcepub fn script() -> NoteScript
pub fn script() -> NoteScript
Returns the CONFIG_AGG_BRIDGE note script.
Sourcepub fn script_root() -> Word
pub fn script_root() -> Word
Returns the CONFIG_AGG_BRIDGE note script root.
Sourcepub fn create<R: FeltRng>(
faucet_account_id: AccountId,
origin_token_address: &EthAddress,
sender_account_id: AccountId,
target_account_id: AccountId,
rng: &mut R,
) -> Result<Note, NoteError>
pub fn create<R: FeltRng>( faucet_account_id: AccountId, origin_token_address: &EthAddress, sender_account_id: AccountId, target_account_id: AccountId, rng: &mut R, ) -> Result<Note, NoteError>
Creates a CONFIG_AGG_BRIDGE note to register a faucet in the bridge’s registry.
The note storage contains 7 felts:
origin_token_addr[0..5]: The 5 u32 felts of the origin EVM token addressfaucet_id_suffix: The suffix of the faucet account IDfaucet_id_prefix: The prefix of the faucet account ID
Parameters
faucet_account_id: The account ID of the faucet to registerorigin_token_address: The origin EVM token address for the token registrysender_account_id: The account ID of the note creatortarget_account_id: The bridge account ID that will consume this noterng: Random number generator for creating the note serial number
Errors
Returns an error if note creation fails.