pub struct UpdateGerNote;Expand description
UPDATE_GER note.
This note is used to update the Global Exit Root (GER) in the bridge account. It carries the new GER data and is always public.
Implementations
Sourceimpl UpdateGerNote
impl UpdateGerNote
Sourcepub const NUM_STORAGE_ITEMS: usize = 8
pub const NUM_STORAGE_ITEMS: usize = 8
Expected number of storage items for an UPDATE_GER note.
Sourcepub fn script() -> NoteScript
pub fn script() -> NoteScript
Returns the UPDATE_GER note script.
Sourcepub fn script_root() -> Word
pub fn script_root() -> Word
Returns the UPDATE_GER note script root.
Sourcepub fn create<R: FeltRng>(
ger: ExitRoot,
sender_account_id: AccountId,
target_account_id: AccountId,
rng: &mut R,
) -> Result<Note, NoteError>
pub fn create<R: FeltRng>( ger: ExitRoot, sender_account_id: AccountId, target_account_id: AccountId, rng: &mut R, ) -> Result<Note, NoteError>
Creates an UPDATE_GER note with the given GER (Global Exit Root) data.
The note storage contains 8 felts: GER[0..7]
Parameters
ger: The Global Exit Root datasender_account_id: The account ID of the note creatortarget_account_id: The account ID that will consume this note (bridge account)rng: Random number generator for creating the note serial number
Errors
Returns an error if note creation fails.